@@ -1,5 +1,5 @@
 import urllib
-from urlparse import urlsplit
+from urlparse import urlsplit, urljoin
 
 from django.conf import settings
 from django.contrib.auth import REDIRECT_FIELD_NAME, authenticate, login
@@ -46,7 +46,11 @@ def login_begin(request, redirect_field_name=REDIRECT_FIELD_NAME,
         sreg.SRegRequest(optional=get_sreg_settings())
     )
 
-    return_to = request.build_absolute_uri(reverse(login_complete))
+    if hasattr(settings, 'OPENID_CUSTOM_RETURN_TO'):
+        return_to = getattr(settings, 'OPENID_CUSTOM_RETURN_TO') + reverse(login_complete)
+    else:
+        return_to = request.build_absolute_uri(reverse(login_complete))
+
     if redirect_to:
         return_to += '&' if '?' in return_to else '?'
         return_to += urllib.urlencode({redirect_field_name: redirect_to})
